Learn R Programming

CRFCSD (version 3.1)

CRFCSD-package: CRFCSD

Description

A methodology to estimate the parameters for the cure rate frailty models with clustered current status data.

Arguments